;; Generated package description from drepl.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "drepl" "0.4.0.20260715.8" "REPL protocol for the dumb terminal" '((emacs "29.1") (comint-mime "0.7")) :commit "f8a9239a42962c150c4dce2353e9cf1b5dc504cf" :authors '(("Augusto Stoffel" . "arstoffel@gmail.com")) :maintainer '("Augusto Stoffel" . "arstoffel@gmail.com") :keywords '("languages" "processes") :url "https://github.com/astoff/drepl")
